TelegramLoginError class
Error thrown when Telegram Login fails.
Constructors
- TelegramLoginError({required TelegramLoginErrorCode code, String? message, int? statusCode})
-
const
- TelegramLoginError.cancelled()
-
factory
- TelegramLoginError.networkError([String? message])
-
factory
- TelegramLoginError.noAuthorizationCode()
-
factory
- TelegramLoginError.notConfigured()
-
factory
- TelegramLoginError.platformError(String message)
-
factory
- TelegramLoginError.requestFailed([String? reason])
-
factory
- TelegramLoginError.serverError([int? statusCode])
-
factory
Properties
- code → TelegramLoginErrorCode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited