TelegramLoginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • TelegramLoginPlatform
Implementers

Constructors

TelegramLoginPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
isConfigured bool
Whether the SDK is configured.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelLogin() Future<bool>
Cancel the in-flight login. Cancel is terminal; late native results are discarded.
configure(TelegramLoginConfiguration config) Future<void>
Configure the SDK.
handleUrl(Uri url) Future<bool>
Handle a callback URL.
login() Future<TelegramLoginResult>
Start the login flow.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TelegramLoginPlatform
Default platform instance.
getter/setter pair