TelegramLoginConfiguration class
Configuration for Telegram Login.
Constructors
-
TelegramLoginConfiguration({required String clientId, required String redirectUri, required List<
String> scopes, String? fallbackScheme}) -
const
-
TelegramLoginConfiguration.fromMap(Map<
String, dynamic> map) -
factory
Properties
- clientId → String
-
final
- fallbackScheme → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- redirectUri → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited